==> karchiver-3.1.1.tar.bz2: karchiver-3.1.1/karchiver/cajoutfichiers.cpp <==
/***************************************************************************
                          cajoutfichiers.cpp  -  description
                             -------------------
    begin                : Thu Jun 3 1999
    copyright            : (C) 2000 by Eric Coquelle
    email                : coquelle@caramail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qpixmap.h>
#include <qlayout.h>
#include <qdragobject.h>
#include <qpainter.h>

#include "cajoutfichiers.h"

#include <kdebug.h>
#include <kiconloader.h>
#define Inherited QDialog


/***************************************************************************
 *  Methods of liste class
 *
 *
 ***************************************************************************/

liste::liste (QWidget* parent, const char* name):QListView( parent, name )
{
  connect(this, SIGNAL(selectionChanged()), this, SLOT(checkSelectionChanged()));
}

/*Send a message each time a file is selected
	files are items that do not have a pixmap*/
void liste::checkSelectionChanged()
{
  QListViewItem* l=currentItem();
  if((l!=0)&&(l->pixmap(0)==NULL))
    emit selectionChangee(l);
}
  

/***************************************************************************
 *  Methods of textEdit class
 *
 *
 ***************************************************************************/
textEdit::textEdit(QWidget* parent, const char* name):QTextEdit( parent, name )
{
        setAcceptDrops(true);
}

void textEdit::contentsDragEnterEvent(QDragEnterEvent* event)
{
       event->accept(QUriDrag::canDecode(event));
}

void textEdit::contentsDropEvent(QDropEvent* drop)
{
        QStringList strlist;
        QUriDrag::decodeToUnicodeUris( drop, strlist);
        kdDebug()<<QString("Drop on TextEdit")<<endl;
        emit newFilesAdded(strlist);
}

/***************************************************************************
 *  Methods of CAddFilesToArchive class
 *
 *
 ***************************************************************************/
	
CAddFilesToArchive::CAddFilesToArchive(QDialog* parent,const char* name)
:QDialog( parent, name, TRUE )
{
	KIconLoader icone;
	setIcon(icone.loadIcon("karchiver",KIcon::Small));

   QGridLayout *grid1 = new QGridLayout(this,8,3,15,7);
   listView = new liste( this, "ListView ajoutfichiers" );
   listView->setFrameStyle( 0 );
   listView->setLineWidth( 1 );
   listView->setMidLineWidth( 0 );
   listView->QFrame::setMargin( 0 );
   listView->setTreeStepSize( 20 );
   listView->setAllColumnsShowFocus( FALSE );
   listView->setItemMargin( 1 );
   listView->addColumn( i18n("Choose files:"), -1 );
   listView->setColumnWidthMode( 0, QListView::Maximum );
   listView->setColumnAlignment( 0, 1 );
   listView->setMultiSelection(TRUE);	
   grid1->addMultiCellWidget(listView,0,7,0,0);

   directory=new Directory(listView);
   directory->setDisplayFiles(TRUE);
   directory->setOpen(TRUE);
   connect(listView, SIGNAL(selectionChangee(QListViewItem*)), this, SLOT(slotSelectionModifiee(QListViewItem*)));
   
   QButtonGroup* qtarch_ButtonGroup;
   qtarch_ButtonGroup = new QButtonGroup( this, "ButtonGroup" );
   qtarch_ButtonGroup->setFocusPolicy( QWidget::NoFocus );
   qtarch_ButtonGroup->setBackgroundMode( QWidget::PaletteBackground );
   qtarch_ButtonGroup->setFrameStyle( 49 );
   qtarch_ButtonGroup->setLineWidth( 1 );
   qtarch_ButtonGroup->setMidLineWidth( 0 );
   qtarch_ButtonGroup->QFrame::setMargin( 0 );
   qtarch_ButtonGroup->setTitle( i18n("Kind of Operation:") );
   qtarch_ButtonGroup->setAlignment( 1 );
   qtarch_ButtonGroup->setExclusive( FALSE );
   grid1->addMultiCellWidget( qtarch_ButtonGroup,0,3,1,2);

   connect(qtarch_ButtonGroup,SIGNAL(clicked(int)), this, SLOT(selectionneMotif(int)));

   QGridLayout *grid2 = new QGridLayout(qtarch_ButtonGroup,3,1,15,7); 
   qtarch_RadioAjoute = new QRadioButton( qtarch_ButtonGroup, "RadioAjoute" );
   qtarch_RadioAjoute->setFocusPolicy( QWidget::TabFocus );
   qtarch_RadioAjoute->setBackgroundMode( QWidget::PaletteBackground );
   qtarch_RadioAjoute->setText( i18n("Add files") );
   qtarch_RadioAjoute->setAutoRepeat( FALSE );
   qtarch_RadioAjoute->setAutoResize( FALSE );
   qtarch_RadioAjoute->setChecked( TRUE );
   grid2->addWidget(qtarch_RadioAjoute,0,0);


   qtarch_RadioUpdate = new QRadioButton( qtarch_ButtonGroup, "RadioUpdate" );
   qtarch_RadioUpdate->setFocusPolicy( QWidget::TabFocus );
   qtarch_RadioUpdate->setBackgroundMode( QWidget::PaletteBackground );
   qtarch_RadioUpdate->setText( i18n("Update files") );
   qtarch_RadioUpdate->setAutoRepeat( FALSE );
   qtarch_RadioUpdate->setAutoResize( FALSE );
   qtarch_RadioUpdate->setChecked( FALSE );
   grid2->addWidget(qtarch_RadioUpdate,1,0);

   qtarch_RadioMotif = new QRadioButton( qtarch_ButtonGroup, "RadioMotif" );
   grid2->addWidget(qtarch_RadioMotif,2,0);
   qtarch_RadioMotif->setText( i18n("Use wildcards") );
   qtarch_RadioMotif->setChecked( FALSE );

   qtarch_CheckBox = new QCheckBox( this, "CheckBox" );
   grid1->addMultiCellWidget(qtarch_CheckBox,4,4,1,2);
   qtarch_CheckBox->setFocusPolicy( QWidget::TabFocus );
   qtarch_CheckBox->setBackgroundMode( QWidget::PaletteBackground );
   qtarch_CheckBox->setText( i18n("Delete source files") );
   qtarch_CheckBox->setAutoRepeat( FALSE );
   qtarch_CheckBox->setAutoResize( FALSE );
   qtarch_CheckBox->setChecked( FALSE );

   QPushButton* qtarch_PushOK;
   qtarch_PushOK = new QPushButton( this, "PushOK" );
   grid1->addWidget(qtarch_PushOK,7,1);
   qtarch_PushOK->setFocusPolicy( QWidget::TabFocus );
   qtarch_PushOK->setBackgroundMode( QWidget::PaletteBackground );
   qtarch_PushOK->setText( i18n("OK") );
   qtarch_PushOK->setAutoRepeat( FALSE );
   qtarch_PushOK->setAutoResize( FALSE );
   qtarch_PushOK->setToggleButton( FALSE );
   qtarch_PushOK->setDefault( FALSE );
   qtarch_PushOK->setAutoDefault( FALSE );
   qtarch_PushOK->setIsMenuButton( FALSE );
   connect(qtarch_PushOK,SIGNAL(clicked()),SLOT(OK()));

   QPushButton* qtarch_PushCancel;
   qtarch_PushCancel = new QPushButton( this, "PushCancel" );
   grid1->addWidget(qtarch_PushCancel,7,2);
   qtarch_PushCancel->setText( i18n("Cancel") );
   connect(qtarch_PushCancel,SIGNAL(clicked()),SLOT(Cancel()));

   qtarch_LineFichiers = new textEdit( this, "LineFichiers" );
   qtarch_LineFichiers->setTextFormat(Qt::PlainText);
   grid1->addMultiCellWidget( qtarch_LineFichiers ,5,6,1,2);
   pix.resize(200,150);
   pix.fill(Qt::white);
   QPainter p(&pix);
   p.setPen(Qt::lightGray);
   p.rotate(-45);
   p.drawText(0,100,i18n("Drop files here"));
   qtarch_LineFichiers->setPaletteBackgroundPixmap(pix);
   connect(qtarch_LineFichiers, SIGNAL(newFilesAdded(QStringList)), SLOT(newFiles(QStringList)));
   kdDebug()<<QString("%1").arg(7&4)<<endl;
   qtarch_ButtonGroup->insert( qtarch_RadioAjoute );
   qtarch_ButtonGroup->insert( qtarch_RadioUpdate );
   qtarch_ButtonGroup->insert( qtarch_RadioMotif );
   setAcceptDrops(true);
   resize( 400,305 );
   path="";
}


CAddFilesToArchive::~CAddFilesToArchive()
{
}

void CAddFilesToArchive::rebuildPath(QListViewItem *l)
{
	if(l->depth()!=0)
	{
		path="/"+path;
		path=l->text(0)+path;
		rebuildPath(l->parent());
	}
	else
	{
		path="/"+path;
		QString str;
		int i;
		i=0;

		for (QString f = filelist.first(); f; f = filelist.next())
		  {
		    str=f;
		    if(str==path)
        {
          filelist.remove(str);
          qtarch_LineFichiers->removeParagraph(i);
          path="";
          return;
        }
		    i++;
		  }
		filelist.append(path);
		qtarch_LineFichiers->append(path);
		path="";
	}
}

QStrList CAddFilesToArchive::getFichiers()
{
	return filelist;
}

void CAddFilesToArchive::OK()
{
	done(0);
}

void CAddFilesToArchive::Cancel()
{
	done(1);
}

int CAddFilesToArchive::getAction()
{
	if(qtarch_RadioAjoute->isChecked())
		return 0;
	else	if(qtarch_RadioUpdate->isChecked())
		return 1;
	return -1;
}

/* Return true if source files should be removed */
bool CAddFilesToArchive::getRemoveFiles()
{
	return qtarch_CheckBox->isChecked();
}

void CAddFilesToArchive::selectionneMotif(int i)
{
	if(i==2)
	{
		QStrList filelist2;
		QStringList unicodefilelist;
		
		unicodefilelist=QFileDialog::getOpenFileNames("",QDir::homeDirPath());

		filelist.clear();		
    for ( QStringList::Iterator it = unicodefilelist.begin(); it != unicodefilelist.end(); ++it ) {
			filelist.append((*it).latin1());
		}

		filelist2=filelist;
		qtarch_LineFichiers->clear();

	  for (QString f = filelist.first(); f; f = filelist.next())
   		qtarch_LineFichiers->append(f);
   		
		filelist=filelist2;
	}
}

void CAddFilesToArchive::MAJMotif()
{
	if(qtarch_RadioMotif->isChecked())
	{
		QString txt;

    txt+="/";
		filelist.clear();
		filelist.append(txt);
	}
}

void CAddFilesToArchive::slotSelectionModifiee(QListViewItem* l)
{
  rebuildPath(l);
}

void CAddFilesToArchive::newFiles(QStringList strlist)
{
        for ( QStringList::Iterator it = strlist.begin(); it != strlist.end(); ++it ) {
                filelist.append((*it).latin1());
                qtarch_LineFichiers->append((*it).latin1());
        }
}

#include "cajoutfichiers.moc"

==> karchiver-3.4.2.b4.tar.bz2: karchiver-3.4.2.b4/karchiver/cajoutfichiers.cpp <==
/***************************************************************************
                          cajoutfichiers.cpp  -  description
                             -------------------
    begin                : Thu Jun 3 1999
    copyright            : (C) 2000 by Eric Coquelle
    email                : coquelle@caramail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qpixmap.h>
#include <qlayout.h>

#include "cajoutfichiers.h"

#include <kiconloader.h>
	
	
CAddFilesToArchive::CAddFilesToArchive(QDialog* parent,const char* name)
:QDialog( parent, name, TRUE )
{
   KIconLoader icon;
   setIcon(icon.loadIcon("karchiver",KIcon::Small));
   setCaption(i18n("Add files to current archive"));
   
   QGridLayout *grid1 = new QGridLayout(this,8,3,15,7);
   listView = new KListView( this, "ListView_AddFiles" );
   listView->addColumn( i18n("Choose files:"), -1 );
   listView->setSelectionModeExt(KListView::Single);
   grid1->addMultiCellWidget(listView,0,7,0,0);

   directory=new Directory(listView);
   directory->setDisplayFiles(TRUE);
   directory->setOpen(TRUE);
   connect(listView, SIGNAL(executed ( QListViewItem *)), this, SLOT(slotSelectionChanged(QListViewItem*)));

   QButtonGroup* qtarch_ButtonGroup;
   qtarch_ButtonGroup = new QButtonGroup( this, "ButtonGroup" );
   qtarch_ButtonGroup->setFocusPolicy( QWidget::NoFocus );
   qtarch_ButtonGroup->setBackgroundMode( QWidget::PaletteBackground );
   qtarch_ButtonGroup->setFrameStyle( 49 );
   qtarch_ButtonGroup->setLineWidth( 1 );
   qtarch_ButtonGroup->setMidLineWidth( 0 );
   qtarch_ButtonGroup->QFrame::setMargin( 0 );
   qtarch_ButtonGroup->setTitle( i18n("Kind of Operation:") );
   qtarch_ButtonGroup->setAlignment( 1 );
   qtarch_ButtonGroup->setExclusive( FALSE );
   grid1->addMultiCellWidget( qtarch_ButtonGroup,0,2,1,2);

   QGridLayout *grid2 = new QGridLayout(qtarch_ButtonGroup,3,1,15,7); 
   qtarch_RadioAdd = new QRadioButton( qtarch_ButtonGroup, "RadioAdd" );
   qtarch_RadioAdd->setFocusPolicy( QWidget::TabFocus );
   qtarch_RadioAdd->setBackgroundMode( QWidget::PaletteBackground );
   qtarch_RadioAdd->setText( i18n("Add files") );
   qtarch_RadioAdd->setAutoRepeat( FALSE );
   qtarch_RadioAdd->setAutoResize( FALSE );
   qtarch_RadioAdd->setChecked( TRUE );
   grid2->addWidget(qtarch_RadioAdd,0,0);


   qtarch_RadioUpdate = new QRadioButton( qtarch_ButtonGroup, "RadioUpdate" );
   qtarch_RadioUpdate->setFocusPolicy( QWidget::TabFocus );
   qtarch_RadioUpdate->setBackgroundMode( QWidget::PaletteBackground );
   qtarch_RadioUpdate->setText( i18n("Update files") );
   qtarch_RadioUpdate->setAutoRepeat( FALSE );
   qtarch_RadioUpdate->setAutoResize( FALSE );
   qtarch_RadioUpdate->setChecked( FALSE );
   grid2->addWidget(qtarch_RadioUpdate,1,0);

   qtarch_Motif = new QPushButton( this, "Button_Dialog" );
   grid1->addMultiCellWidget(qtarch_Motif,3,3,1,2);
   qtarch_Motif->setText( i18n("Use a dialog box") );
   connect(qtarch_Motif,SIGNAL(clicked()),SLOT(slotGetFilesFromDialogBox()));

   qtarch_CheckBox = new QCheckBox( this, "CheckBox" );
   grid1->addMultiCellWidget(qtarch_CheckBox,4,4,1,2);
   qtarch_CheckBox->setFocusPolicy( QWidget::TabFocus );
   qtarch_CheckBox->setBackgroundMode( QWidget::PaletteBackground );
   qtarch_CheckBox->setText( i18n("Delete source files") );
   qtarch_CheckBox->setAutoRepeat( FALSE );
   qtarch_CheckBox->setAutoResize( FALSE );
   qtarch_CheckBox->setChecked( FALSE );

   QPushButton* qtarch_PushOK;
   qtarch_PushOK = new QPushButton( this, "PushOK" );
   grid1->addWidget(qtarch_PushOK,7,1);
   qtarch_PushOK->setFocusPolicy( QWidget::TabFocus );
   qtarch_PushOK->setBackgroundMode( QWidget::PaletteBackground );
   qtarch_PushOK->setText( i18n("OK") );
   qtarch_PushOK->setAutoRepeat( FALSE );
   qtarch_PushOK->setAutoResize( FALSE );
   qtarch_PushOK->setToggleButton( FALSE );
   qtarch_PushOK->setDefault( FALSE );
   qtarch_PushOK->setAutoDefault( FALSE );
   qtarch_PushOK->setIsMenuButton( FALSE );
   connect(qtarch_PushOK,SIGNAL(clicked()),SLOT(OK()));

   QPushButton* qtarch_PushCancel;
   qtarch_PushCancel = new QPushButton( this, "PushCancel" );
   grid1->addWidget(qtarch_PushCancel,7,2);
   qtarch_PushCancel->setText( i18n("Cancel") );
   connect(qtarch_PushCancel,SIGNAL(clicked()),SLOT(Cancel()));

   qtarch_LineFichiers = new QTextEdit( this, "LineFichiers" );
   grid1->addMultiCellWidget( qtarch_LineFichiers ,5,6,1,2);
   
   qtarch_ButtonGroup->insert( qtarch_RadioAdd );
   qtarch_ButtonGroup->insert( qtarch_RadioUpdate );
   
   resize( 400,305 );
   path="";
}


CAddFilesToArchive::~CAddFilesToArchive()
{
}

void CAddFilesToArchive::rebuildPath(QListViewItem *l)
{
	if(l->depth()!=0)
	{
		path="/"+path;
		path=l->text(0)+path;
		rebuildPath(l->parent());
	}
	else
	{
		path="/"+path;
		QString str;
		int i;
		i=0;

		for (QString f = filelist.first(); f; f = filelist.next())
		  {
		    str=f;
		    if(str==path)
        {
          filelist.remove(str);
          qtarch_LineFichiers->removeParagraph(i);
          path="";
          return;
        }
		    i++;
		  }
		filelist.append(path);
		qtarch_LineFichiers->insertParagraph(path, -1);
		path="";
	}
}

QStrList CAddFilesToArchive::getFiles()
{
	return filelist;
}

void CAddFilesToArchive::OK()
{
	done(0);
}

void CAddFilesToArchive::Cancel()
{
	done(1);
}

int CAddFilesToArchive::getAction()
{
  if(qtarch_RadioAdd->isChecked())
   return ADD_AND_REPLACE_FILES;
  else if(qtarch_RadioUpdate->isChecked())
   return UPDATE_FILES;
  return -1;
}

/* Return true if source files should be removed */
bool CAddFilesToArchive::hasToRemoveFiles()
{
	return qtarch_CheckBox->isChecked();
}

void CAddFilesToArchive::selectionneMotif(int i)
{
	if(i==2)
	{
		QStrList filelist2;
		QStringList unicodefilelist;
		
		unicodefilelist=QFileDialog::getOpenFileNames("",QDir::homeDirPath());

		filelist.clear();		
    for ( QStringList::Iterator it = unicodefilelist.begin(); it != unicodefilelist.end(); ++it ) {
			filelist.append((*it).latin1());
		}

		filelist2=filelist;
		qtarch_LineFichiers->clear();

	  for (QString f = filelist.first(); f; f = filelist.next())
   		qtarch_LineFichiers->insertParagraph(f, -1);
   		
		filelist=filelist2;
	}
}

void CAddFilesToArchive::slotGetFilesFromDialogBox()
{
  QStrList filelist2;
  QStringList unicodefilelist;
		
  unicodefilelist=KFileDialog::getOpenFileNames(QDir::homeDirPath(), "", 0, i18n("Select the files to add in archive"));

  filelist.clear();		
  for ( QStringList::Iterator it = unicodefilelist.begin(); it != unicodefilelist.end(); ++it ) {
    filelist.append((*it).latin1());
  }

  filelist2=filelist;
  qtarch_LineFichiers->clear();

  for (QString f = filelist.first(); f; f = filelist.next())
    qtarch_LineFichiers->insertParagraph(f, -1);
   		
  filelist=filelist2;
}

void CAddFilesToArchive::slotSelectionChanged(QListViewItem* l)
{
   rebuildPath(l);

   if(l->pixmap(0)!=NULL)//It is a directory, so let's remove all its childs
   {
     int number=filelist.count();
     int i=0;
     QString ref=filelist.at(number-1);
     
     while(i<number-1)
     {
       if(QString(filelist.at(i)).startsWith(ref))
       {
         filelist.remove(i);
         qtarch_LineFichiers->removeParagraph(i);
         number--;
       }
       else
         i++;
     }
   }
}

#include "cajoutfichiers.moc"
